@@ -3,8 +3,9 @@ Main interface for iotanalytics service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iotanalytics import (
+    from mypy_boto3_iotanalytics import (
         Client,
         IoTAnalyticsClient,
         ListChannelsPaginator,
@@ -12,7 +13,7 @@ Usage::
         ListDatasetsPaginator,
         ListDatastoresPaginator,
         ListPipelinesPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -24,6 +25,7 @@ Usage::
     list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
     list_datastores_paginator: ListDatastoresPaginator = client.get_paginator("list_datastores")
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
+    ```
 """
 from mypy_boto3_iotanalytics.client import IoTAnalyticsClient, IoTAnalyticsClient as Client
 from mypy_boto3_iotanalytics.paginator import (
