@@ -3,13 +3,15 @@ Main interface for iotanalytics service type definitions.
 
 Usage::
 
-    from mypy_boto3.iotanalytics.type_defs import BatchPutMessageErrorEntryTypeDef
+    ```python
+    from mypy_boto3_iotanalytics.type_defs import AddAttributesActivityTypeDef
 
-    data: BatchPutMessageErrorEntryTypeDef = {...}
+    data: AddAttributesActivityTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
-from typing import Any, Dict, IO, List, Union
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -22,80 +24,80 @@ else:
 
 
 __all__ = (
+    "AddAttributesActivityTypeDef",
     "BatchPutMessageErrorEntryTypeDef",
-    "BatchPutMessageResponseTypeDef",
-    "CustomerManagedChannelS3StorageTypeDef",
+    "ChannelActivityTypeDef",
+    "ChannelStatisticsTypeDef",
+    "ChannelStorageSummaryTypeDef",
     "ChannelStorageTypeDef",
+    "ChannelSummaryTypeDef",
+    "ChannelTypeDef",
+    "ContainerDatasetActionTypeDef",
+    "CustomerManagedChannelS3StorageSummaryTypeDef",
+    "CustomerManagedChannelS3StorageTypeDef",
+    "CustomerManagedDatastoreS3StorageSummaryTypeDef",
+    "CustomerManagedDatastoreS3StorageTypeDef",
+    "DatasetActionSummaryTypeDef",
+    "DatasetActionTypeDef",
+    "DatasetContentDeliveryDestinationTypeDef",
+    "DatasetContentDeliveryRuleTypeDef",
+    "DatasetContentStatusTypeDef",
+    "DatasetContentSummaryTypeDef",
+    "DatasetContentVersionValueTypeDef",
+    "DatasetEntryTypeDef",
+    "DatasetSummaryTypeDef",
+    "DatasetTriggerTypeDef",
+    "DatasetTypeDef",
+    "DatastoreActivityTypeDef",
+    "DatastoreStatisticsTypeDef",
+    "DatastoreStorageSummaryTypeDef",
+    "DatastoreStorageTypeDef",
+    "DatastoreSummaryTypeDef",
+    "DatastoreTypeDef",
+    "DeltaTimeTypeDef",
+    "DeviceRegistryEnrichActivityTypeDef",
+    "DeviceShadowEnrichActivityTypeDef",
+    "EstimatedResourceSizeTypeDef",
+    "FilterActivityTypeDef",
+    "GlueConfigurationTypeDef",
+    "IotEventsDestinationConfigurationTypeDef",
+    "LambdaActivityTypeDef",
+    "LoggingOptionsTypeDef",
+    "MathActivityTypeDef",
+    "OutputFileUriValueTypeDef",
+    "PipelineActivityTypeDef",
+    "PipelineSummaryTypeDef",
+    "PipelineTypeDef",
+    "QueryFilterTypeDef",
+    "RemoveAttributesActivityTypeDef",
+    "ReprocessingSummaryTypeDef",
+    "ResourceConfigurationTypeDef",
     "RetentionPeriodTypeDef",
+    "S3DestinationConfigurationTypeDef",
+    "ScheduleTypeDef",
+    "SelectAttributesActivityTypeDef",
+    "SqlQueryDatasetActionTypeDef",
+    "TagTypeDef",
+    "TriggeringDatasetTypeDef",
+    "VariableTypeDef",
+    "VersioningConfigurationTypeDef",
+    "BatchPutMessageResponseTypeDef",
     "CreateChannelResponseTypeDef",
     "CreateDatasetContentResponseTypeDef",
     "CreateDatasetResponseTypeDef",
     "CreateDatastoreResponseTypeDef",
     "CreatePipelineResponseTypeDef",
-    "ResourceConfigurationTypeDef",
-    "DatasetContentVersionValueTypeDef",
-    "OutputFileUriValueTypeDef",
-    "VariableTypeDef",
-    "ContainerDatasetActionTypeDef",
-    "DeltaTimeTypeDef",
-    "QueryFilterTypeDef",
-    "SqlQueryDatasetActionTypeDef",
-    "DatasetActionTypeDef",
-    "IotEventsDestinationConfigurationTypeDef",
-    "GlueConfigurationTypeDef",
-    "S3DestinationConfigurationTypeDef",
-    "DatasetContentDeliveryDestinationTypeDef",
-    "DatasetContentDeliveryRuleTypeDef",
-    "ScheduleTypeDef",
-    "TriggeringDatasetTypeDef",
-    "DatasetTriggerTypeDef",
-    "CustomerManagedDatastoreS3StorageTypeDef",
-    "DatastoreStorageTypeDef",
-    "EstimatedResourceSizeTypeDef",
-    "ChannelStatisticsTypeDef",
-    "ChannelTypeDef",
     "DescribeChannelResponseTypeDef",
-    "VersioningConfigurationTypeDef",
-    "DatasetTypeDef",
     "DescribeDatasetResponseTypeDef",
-    "DatastoreStatisticsTypeDef",
-    "DatastoreTypeDef",
     "DescribeDatastoreResponseTypeDef",
-    "LoggingOptionsTypeDef",
     "DescribeLoggingOptionsResponseTypeDef",
-    "AddAttributesActivityTypeDef",
-    "ChannelActivityTypeDef",
-    "DatastoreActivityTypeDef",
-    "DeviceRegistryEnrichActivityTypeDef",
-    "DeviceShadowEnrichActivityTypeDef",
-    "FilterActivityTypeDef",
-    "LambdaActivityTypeDef",
-    "MathActivityTypeDef",
-    "RemoveAttributesActivityTypeDef",
-    "SelectAttributesActivityTypeDef",
-    "PipelineActivityTypeDef",
-    "ReprocessingSummaryTypeDef",
-    "PipelineTypeDef",
     "DescribePipelineResponseTypeDef",
-    "DatasetContentStatusTypeDef",
-    "DatasetEntryTypeDef",
     "GetDatasetContentResponseTypeDef",
-    "CustomerManagedChannelS3StorageSummaryTypeDef",
-    "ChannelStorageSummaryTypeDef",
-    "ChannelSummaryTypeDef",
     "ListChannelsResponseTypeDef",
-    "DatasetContentSummaryTypeDef",
     "ListDatasetContentsResponseTypeDef",
-    "DatasetActionSummaryTypeDef",
-    "DatasetSummaryTypeDef",
     "ListDatasetsResponseTypeDef",
-    "CustomerManagedDatastoreS3StorageSummaryTypeDef",
-    "DatastoreStorageSummaryTypeDef",
-    "DatastoreSummaryTypeDef",
     "ListDatastoresResponseTypeDef",
-    "PipelineSummaryTypeDef",
     "ListPipelinesResponseTypeDef",
-    "TagTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "MessageTypeDef",
     "PaginatorConfigTypeDef",
@@ -104,15 +106,108 @@ __all__ = (
     "StartPipelineReprocessingResponseTypeDef",
 )
 
+_RequiredAddAttributesActivityTypeDef = TypedDict(
+    "_RequiredAddAttributesActivityTypeDef", {"name": str, "attributes": Dict[str, str]}
+)
+_OptionalAddAttributesActivityTypeDef = TypedDict(
+    "_OptionalAddAttributesActivityTypeDef", {"next": str}, total=False
+)
+
+
+class AddAttributesActivityTypeDef(
+    _RequiredAddAttributesActivityTypeDef, _OptionalAddAttributesActivityTypeDef
+):
+    pass
+
+
 BatchPutMessageErrorEntryTypeDef = TypedDict(
     "BatchPutMessageErrorEntryTypeDef",
     {"messageId": str, "errorCode": str, "errorMessage": str},
     total=False,
 )
 
-BatchPutMessageResponseTypeDef = TypedDict(
-    "BatchPutMessageResponseTypeDef",
-    {"batchPutMessageErrorEntries": List[BatchPutMessageErrorEntryTypeDef]},
+_RequiredChannelActivityTypeDef = TypedDict(
+    "_RequiredChannelActivityTypeDef", {"name": str, "channelName": str}
+)
+_OptionalChannelActivityTypeDef = TypedDict(
+    "_OptionalChannelActivityTypeDef", {"next": str}, total=False
+)
+
+
+class ChannelActivityTypeDef(_RequiredChannelActivityTypeDef, _OptionalChannelActivityTypeDef):
+    pass
+
+
+ChannelStatisticsTypeDef = TypedDict(
+    "ChannelStatisticsTypeDef", {"size": "EstimatedResourceSizeTypeDef"}, total=False
+)
+
+ChannelStorageSummaryTypeDef = TypedDict(
+    "ChannelStorageSummaryTypeDef",
+    {
+        "serviceManagedS3": Dict[str, Any],
+        "customerManagedS3": "CustomerManagedChannelS3StorageSummaryTypeDef",
+    },
+    total=False,
+)
+
+ChannelStorageTypeDef = TypedDict(
+    "ChannelStorageTypeDef",
+    {
+        "serviceManagedS3": Dict[str, Any],
+        "customerManagedS3": "CustomerManagedChannelS3StorageTypeDef",
+    },
+    total=False,
+)
+
+ChannelSummaryTypeDef = TypedDict(
+    "ChannelSummaryTypeDef",
+    {
+        "channelName": str,
+        "channelStorage": "ChannelStorageSummaryTypeDef",
+        "status": Literal["CREATING", "ACTIVE", "DELETING"],
+        "creationTime": datetime,
+        "lastUpdateTime": datetime,
+    },
+    total=False,
+)
+
+ChannelTypeDef = TypedDict(
+    "ChannelTypeDef",
+    {
+        "name": str,
+        "storage": "ChannelStorageTypeDef",
+        "arn": str,
+        "status": Literal["CREATING", "ACTIVE", "DELETING"],
+        "retentionPeriod": "RetentionPeriodTypeDef",
+        "creationTime": datetime,
+        "lastUpdateTime": datetime,
+    },
+    total=False,
+)
+
+_RequiredContainerDatasetActionTypeDef = TypedDict(
+    "_RequiredContainerDatasetActionTypeDef",
+    {
+        "image": str,
+        "executionRoleArn": str,
+        "resourceConfiguration": "ResourceConfigurationTypeDef",
+    },
+)
+_OptionalContainerDatasetActionTypeDef = TypedDict(
+    "_OptionalContainerDatasetActionTypeDef", {"variables": List["VariableTypeDef"]}, total=False
+)
+
+
+class ContainerDatasetActionTypeDef(
+    _RequiredContainerDatasetActionTypeDef, _OptionalContainerDatasetActionTypeDef
+):
+    pass
+
+
+CustomerManagedChannelS3StorageSummaryTypeDef = TypedDict(
+    "CustomerManagedChannelS3StorageSummaryTypeDef",
+    {"bucket": str, "keyPrefix": str, "roleArn": str},
     total=False,
 )
 
@@ -130,171 +225,9 @@ class CustomerManagedChannelS3StorageTypeDef(
     pass
 
 
-ChannelStorageTypeDef = TypedDict(
-    "ChannelStorageTypeDef",
-    {
-        "serviceManagedS3": Dict[str, Any],
-        "customerManagedS3": CustomerManagedChannelS3StorageTypeDef,
-    },
-    total=False,
-)
-
-RetentionPeriodTypeDef = TypedDict(
-    "RetentionPeriodTypeDef", {"unlimited": bool, "numberOfDays": int}, total=False
-)
-
-CreateChannelResponseTypeDef = TypedDict(
-    "CreateChannelResponseTypeDef",
-    {"channelName": str, "channelArn": str, "retentionPeriod": RetentionPeriodTypeDef},
-    total=False,
-)
-
-CreateDatasetContentResponseTypeDef = TypedDict(
-    "CreateDatasetContentResponseTypeDef", {"versionId": str}, total=False
-)
-
-CreateDatasetResponseTypeDef = TypedDict(
-    "CreateDatasetResponseTypeDef",
-    {"datasetName": str, "datasetArn": str, "retentionPeriod": RetentionPeriodTypeDef},
-    total=False,
-)
-
-CreateDatastoreResponseTypeDef = TypedDict(
-    "CreateDatastoreResponseTypeDef",
-    {"datastoreName": str, "datastoreArn": str, "retentionPeriod": RetentionPeriodTypeDef},
-    total=False,
-)
-
-CreatePipelineResponseTypeDef = TypedDict(
-    "CreatePipelineResponseTypeDef", {"pipelineName": str, "pipelineArn": str}, total=False
-)
-
-ResourceConfigurationTypeDef = TypedDict(
-    "ResourceConfigurationTypeDef",
-    {"computeType": Literal["ACU_1", "ACU_2"], "volumeSizeInGB": int},
-)
-
-DatasetContentVersionValueTypeDef = TypedDict(
-    "DatasetContentVersionValueTypeDef", {"datasetName": str}
-)
-
-OutputFileUriValueTypeDef = TypedDict("OutputFileUriValueTypeDef", {"fileName": str})
-
-_RequiredVariableTypeDef = TypedDict("_RequiredVariableTypeDef", {"name": str})
-_OptionalVariableTypeDef = TypedDict(
-    "_OptionalVariableTypeDef",
-    {
-        "stringValue": str,
-        "doubleValue": float,
-        "datasetContentVersionValue": DatasetContentVersionValueTypeDef,
-        "outputFileUriValue": OutputFileUriValueTypeDef,
-    },
-    total=False,
-)
-
-
-class VariableTypeDef(_RequiredVariableTypeDef, _OptionalVariableTypeDef):
-    pass
-
-
-_RequiredContainerDatasetActionTypeDef = TypedDict(
-    "_RequiredContainerDatasetActionTypeDef",
-    {"image": str, "executionRoleArn": str, "resourceConfiguration": ResourceConfigurationTypeDef},
-)
-_OptionalContainerDatasetActionTypeDef = TypedDict(
-    "_OptionalContainerDatasetActionTypeDef", {"variables": List[VariableTypeDef]}, total=False
-)
-
-
-class ContainerDatasetActionTypeDef(
-    _RequiredContainerDatasetActionTypeDef, _OptionalContainerDatasetActionTypeDef
-):
-    pass
-
-
-DeltaTimeTypeDef = TypedDict("DeltaTimeTypeDef", {"offsetSeconds": int, "timeExpression": str})
-
-QueryFilterTypeDef = TypedDict("QueryFilterTypeDef", {"deltaTime": DeltaTimeTypeDef}, total=False)
-
-_RequiredSqlQueryDatasetActionTypeDef = TypedDict(
-    "_RequiredSqlQueryDatasetActionTypeDef", {"sqlQuery": str}
-)
-_OptionalSqlQueryDatasetActionTypeDef = TypedDict(
-    "_OptionalSqlQueryDatasetActionTypeDef", {"filters": List[QueryFilterTypeDef]}, total=False
-)
-
-
-class SqlQueryDatasetActionTypeDef(
-    _RequiredSqlQueryDatasetActionTypeDef, _OptionalSqlQueryDatasetActionTypeDef
-):
-    pass
-
-
-DatasetActionTypeDef = TypedDict(
-    "DatasetActionTypeDef",
-    {
-        "actionName": str,
-        "queryAction": SqlQueryDatasetActionTypeDef,
-        "containerAction": ContainerDatasetActionTypeDef,
-    },
-    total=False,
-)
-
-IotEventsDestinationConfigurationTypeDef = TypedDict(
-    "IotEventsDestinationConfigurationTypeDef", {"inputName": str, "roleArn": str}
-)
-
-GlueConfigurationTypeDef = TypedDict(
-    "GlueConfigurationTypeDef", {"tableName": str, "databaseName": str}
-)
-
-_RequiredS3DestinationConfigurationTypeDef = TypedDict(
-    "_RequiredS3DestinationConfigurationTypeDef", {"bucket": str, "key": str, "roleArn": str}
-)
-_OptionalS3DestinationConfigurationTypeDef = TypedDict(
-    "_OptionalS3DestinationConfigurationTypeDef",
-    {"glueConfiguration": GlueConfigurationTypeDef},
-    total=False,
-)
-
-
-class S3DestinationConfigurationTypeDef(
-    _RequiredS3DestinationConfigurationTypeDef, _OptionalS3DestinationConfigurationTypeDef
-):
-    pass
-
-
-DatasetContentDeliveryDestinationTypeDef = TypedDict(
-    "DatasetContentDeliveryDestinationTypeDef",
-    {
-        "iotEventsDestinationConfiguration": IotEventsDestinationConfigurationTypeDef,
-        "s3DestinationConfiguration": S3DestinationConfigurationTypeDef,
-    },
-    total=False,
-)
-
-_RequiredDatasetContentDeliveryRuleTypeDef = TypedDict(
-    "_RequiredDatasetContentDeliveryRuleTypeDef",
-    {"destination": DatasetContentDeliveryDestinationTypeDef},
-)
-_OptionalDatasetContentDeliveryRuleTypeDef = TypedDict(
-    "_OptionalDatasetContentDeliveryRuleTypeDef", {"entryName": str}, total=False
-)
-
-
-class DatasetContentDeliveryRuleTypeDef(
-    _RequiredDatasetContentDeliveryRuleTypeDef, _OptionalDatasetContentDeliveryRuleTypeDef
-):
-    pass
-
-
-ScheduleTypeDef = TypedDict("ScheduleTypeDef", {"expression": str}, total=False)
-
-TriggeringDatasetTypeDef = TypedDict("TriggeringDatasetTypeDef", {"name": str})
-
-DatasetTriggerTypeDef = TypedDict(
-    "DatasetTriggerTypeDef",
-    {"schedule": ScheduleTypeDef, "dataset": TriggeringDatasetTypeDef},
+CustomerManagedDatastoreS3StorageSummaryTypeDef = TypedDict(
+    "CustomerManagedDatastoreS3StorageSummaryTypeDef",
+    {"bucket": str, "keyPrefix": str, "roleArn": str},
     total=False,
 )
 
@@ -313,131 +246,161 @@ class CustomerManagedDatastoreS3StorageTypeDef(
     pass
 
 
-DatastoreStorageTypeDef = TypedDict(
-    "DatastoreStorageTypeDef",
+DatasetActionSummaryTypeDef = TypedDict(
+    "DatasetActionSummaryTypeDef",
+    {"actionName": str, "actionType": Literal["QUERY", "CONTAINER"]},
+    total=False,
+)
+
+DatasetActionTypeDef = TypedDict(
+    "DatasetActionTypeDef",
     {
-        "serviceManagedS3": Dict[str, Any],
-        "customerManagedS3": CustomerManagedDatastoreS3StorageTypeDef,
+        "actionName": str,
+        "queryAction": "SqlQueryDatasetActionTypeDef",
+        "containerAction": "ContainerDatasetActionTypeDef",
     },
     total=False,
 )
 
-EstimatedResourceSizeTypeDef = TypedDict(
-    "EstimatedResourceSizeTypeDef",
-    {"estimatedSizeInBytes": float, "estimatedOn": datetime},
+DatasetContentDeliveryDestinationTypeDef = TypedDict(
+    "DatasetContentDeliveryDestinationTypeDef",
+    {
+        "iotEventsDestinationConfiguration": "IotEventsDestinationConfigurationTypeDef",
+        "s3DestinationConfiguration": "S3DestinationConfigurationTypeDef",
+    },
     total=False,
 )
 
-ChannelStatisticsTypeDef = TypedDict(
-    "ChannelStatisticsTypeDef", {"size": EstimatedResourceSizeTypeDef}, total=False
+_RequiredDatasetContentDeliveryRuleTypeDef = TypedDict(
+    "_RequiredDatasetContentDeliveryRuleTypeDef",
+    {"destination": "DatasetContentDeliveryDestinationTypeDef"},
+)
+_OptionalDatasetContentDeliveryRuleTypeDef = TypedDict(
+    "_OptionalDatasetContentDeliveryRuleTypeDef", {"entryName": str}, total=False
 )
 
-ChannelTypeDef = TypedDict(
-    "ChannelTypeDef",
+
+class DatasetContentDeliveryRuleTypeDef(
+    _RequiredDatasetContentDeliveryRuleTypeDef, _OptionalDatasetContentDeliveryRuleTypeDef
+):
+    pass
+
+
+DatasetContentStatusTypeDef = TypedDict(
+    "DatasetContentStatusTypeDef",
+    {"state": Literal["CREATING", "SUCCEEDED", "FAILED"], "reason": str},
+    total=False,
+)
+
+DatasetContentSummaryTypeDef = TypedDict(
+    "DatasetContentSummaryTypeDef",
     {
-        "name": str,
-        "storage": ChannelStorageTypeDef,
-        "arn": str,
+        "version": str,
+        "status": "DatasetContentStatusTypeDef",
+        "creationTime": datetime,
+        "scheduleTime": datetime,
+        "completionTime": datetime,
+    },
+    total=False,
+)
+
+DatasetContentVersionValueTypeDef = TypedDict(
+    "DatasetContentVersionValueTypeDef", {"datasetName": str}
+)
+
+DatasetEntryTypeDef = TypedDict(
+    "DatasetEntryTypeDef", {"entryName": str, "dataURI": str}, total=False
+)
+
+DatasetSummaryTypeDef = TypedDict(
+    "DatasetSummaryTypeDef",
+    {
+        "datasetName": str,
         "status": Literal["CREATING", "ACTIVE", "DELETING"],
-        "retentionPeriod": RetentionPeriodTypeDef,
         "creationTime": datetime,
         "lastUpdateTime": datetime,
+        "triggers": List["DatasetTriggerTypeDef"],
+        "actions": List["DatasetActionSummaryTypeDef"],
     },
     total=False,
 )
 
-DescribeChannelResponseTypeDef = TypedDict(
-    "DescribeChannelResponseTypeDef",
-    {"channel": ChannelTypeDef, "statistics": ChannelStatisticsTypeDef},
+DatasetTriggerTypeDef = TypedDict(
+    "DatasetTriggerTypeDef",
+    {"schedule": "ScheduleTypeDef", "dataset": "TriggeringDatasetTypeDef"},
     total=False,
 )
 
-VersioningConfigurationTypeDef = TypedDict(
-    "VersioningConfigurationTypeDef", {"unlimited": bool, "maxVersions": int}, total=False
-)
-
 DatasetTypeDef = TypedDict(
     "DatasetTypeDef",
     {
         "name": str,
         "arn": str,
-        "actions": List[DatasetActionTypeDef],
-        "triggers": List[DatasetTriggerTypeDef],
-        "contentDeliveryRules": List[DatasetContentDeliveryRuleTypeDef],
+        "actions": List["DatasetActionTypeDef"],
+        "triggers": List["DatasetTriggerTypeDef"],
+        "contentDeliveryRules": List["DatasetContentDeliveryRuleTypeDef"],
         "status": Literal["CREATING", "ACTIVE", "DELETING"],
         "creationTime": datetime,
         "lastUpdateTime": datetime,
-        "retentionPeriod": RetentionPeriodTypeDef,
-        "versioningConfiguration": VersioningConfigurationTypeDef,
+        "retentionPeriod": "RetentionPeriodTypeDef",
+        "versioningConfiguration": "VersioningConfigurationTypeDef",
     },
     total=False,
 )
 
-DescribeDatasetResponseTypeDef = TypedDict(
-    "DescribeDatasetResponseTypeDef", {"dataset": DatasetTypeDef}, total=False
+DatastoreActivityTypeDef = TypedDict(
+    "DatastoreActivityTypeDef", {"name": str, "datastoreName": str}
 )
 
 DatastoreStatisticsTypeDef = TypedDict(
-    "DatastoreStatisticsTypeDef", {"size": EstimatedResourceSizeTypeDef}, total=False
+    "DatastoreStatisticsTypeDef", {"size": "EstimatedResourceSizeTypeDef"}, total=False
+)
+
+DatastoreStorageSummaryTypeDef = TypedDict(
+    "DatastoreStorageSummaryTypeDef",
+    {
+        "serviceManagedS3": Dict[str, Any],
+        "customerManagedS3": "CustomerManagedDatastoreS3StorageSummaryTypeDef",
+    },
+    total=False,
+)
+
+DatastoreStorageTypeDef = TypedDict(
+    "DatastoreStorageTypeDef",
+    {
+        "serviceManagedS3": Dict[str, Any],
+        "customerManagedS3": "CustomerManagedDatastoreS3StorageTypeDef",
+    },
+    total=False,
+)
+
+DatastoreSummaryTypeDef = TypedDict(
+    "DatastoreSummaryTypeDef",
+    {
+        "datastoreName": str,
+        "datastoreStorage": "DatastoreStorageSummaryTypeDef",
+        "status": Literal["CREATING", "ACTIVE", "DELETING"],
+        "creationTime": datetime,
+        "lastUpdateTime": datetime,
+    },
+    total=False,
 )
 
 DatastoreTypeDef = TypedDict(
     "DatastoreTypeDef",
     {
         "name": str,
-        "storage": DatastoreStorageTypeDef,
+        "storage": "DatastoreStorageTypeDef",
         "arn": str,
         "status": Literal["CREATING", "ACTIVE", "DELETING"],
-        "retentionPeriod": RetentionPeriodTypeDef,
+        "retentionPeriod": "RetentionPeriodTypeDef",
         "creationTime": datetime,
         "lastUpdateTime": datetime,
     },
     total=False,
 )
 
-DescribeDatastoreResponseTypeDef = TypedDict(
-    "DescribeDatastoreResponseTypeDef",
-    {"datastore": DatastoreTypeDef, "statistics": DatastoreStatisticsTypeDef},
-    total=False,
-)
-
-LoggingOptionsTypeDef = TypedDict(
-    "LoggingOptionsTypeDef", {"roleArn": str, "level": Literal["ERROR"], "enabled": bool}
-)
-
-DescribeLoggingOptionsResponseTypeDef = TypedDict(
-    "DescribeLoggingOptionsResponseTypeDef", {"loggingOptions": LoggingOptionsTypeDef}, total=False
-)
-
-_RequiredAddAttributesActivityTypeDef = TypedDict(
-    "_RequiredAddAttributesActivityTypeDef", {"name": str, "attributes": Dict[str, str]}
-)
-_OptionalAddAttributesActivityTypeDef = TypedDict(
-    "_OptionalAddAttributesActivityTypeDef", {"next": str}, total=False
-)
-
-
-class AddAttributesActivityTypeDef(
-    _RequiredAddAttributesActivityTypeDef, _OptionalAddAttributesActivityTypeDef
-):
-    pass
-
-
-_RequiredChannelActivityTypeDef = TypedDict(
-    "_RequiredChannelActivityTypeDef", {"name": str, "channelName": str}
-)
-_OptionalChannelActivityTypeDef = TypedDict(
-    "_OptionalChannelActivityTypeDef", {"next": str}, total=False
-)
-
-
-class ChannelActivityTypeDef(_RequiredChannelActivityTypeDef, _OptionalChannelActivityTypeDef):
-    pass
-
-
-DatastoreActivityTypeDef = TypedDict(
-    "DatastoreActivityTypeDef", {"name": str, "datastoreName": str}
-)
+DeltaTimeTypeDef = TypedDict("DeltaTimeTypeDef", {"offsetSeconds": int, "timeExpression": str})
 
 _RequiredDeviceRegistryEnrichActivityTypeDef = TypedDict(
     "_RequiredDeviceRegistryEnrichActivityTypeDef",
@@ -469,6 +432,12 @@ class DeviceShadowEnrichActivityTypeDef(
     pass
 
 
+EstimatedResourceSizeTypeDef = TypedDict(
+    "EstimatedResourceSizeTypeDef",
+    {"estimatedSizeInBytes": float, "estimatedOn": datetime},
+    total=False,
+)
+
 _RequiredFilterActivityTypeDef = TypedDict(
     "_RequiredFilterActivityTypeDef", {"name": str, "filter": str}
 )
@@ -481,6 +450,14 @@ class FilterActivityTypeDef(_RequiredFilterActivityTypeDef, _OptionalFilterActiv
     pass
 
 
+GlueConfigurationTypeDef = TypedDict(
+    "GlueConfigurationTypeDef", {"tableName": str, "databaseName": str}
+)
+
+IotEventsDestinationConfigurationTypeDef = TypedDict(
+    "IotEventsDestinationConfigurationTypeDef", {"inputName": str, "roleArn": str}
+)
+
 _RequiredLambdaActivityTypeDef = TypedDict(
     "_RequiredLambdaActivityTypeDef", {"name": str, "lambdaName": str, "batchSize": int}
 )
@@ -493,6 +470,10 @@ class LambdaActivityTypeDef(_RequiredLambdaActivityTypeDef, _OptionalLambdaActiv
     pass
 
 
+LoggingOptionsTypeDef = TypedDict(
+    "LoggingOptionsTypeDef", {"roleArn": str, "level": Literal["ERROR"], "enabled": bool}
+)
+
 _RequiredMathActivityTypeDef = TypedDict(
     "_RequiredMathActivityTypeDef", {"name": str, "attribute": str, "math": str}
 )
@@ -503,6 +484,51 @@ class MathActivityTypeDef(_RequiredMathActivityTypeDef, _OptionalMathActivityTyp
     pass
 
 
+OutputFileUriValueTypeDef = TypedDict("OutputFileUriValueTypeDef", {"fileName": str})
+
+PipelineActivityTypeDef = TypedDict(
+    "PipelineActivityTypeDef",
+    {
+        "channel": "ChannelActivityTypeDef",
+        "lambda": "LambdaActivityTypeDef",
+        "datastore": "DatastoreActivityTypeDef",
+        "addAttributes": "AddAttributesActivityTypeDef",
+        "removeAttributes": "RemoveAttributesActivityTypeDef",
+        "selectAttributes": "SelectAttributesActivityTypeDef",
+        "filter": "FilterActivityTypeDef",
+        "math": "MathActivityTypeDef",
+        "deviceRegistryEnrich": "DeviceRegistryEnrichActivityTypeDef",
+        "deviceShadowEnrich": "DeviceShadowEnrichActivityTypeDef",
+    },
+    total=False,
+)
+
+PipelineSummaryTypeDef = TypedDict(
+    "PipelineSummaryTypeDef",
+    {
+        "pipelineName": str,
+        "reprocessingSummaries": List["ReprocessingSummaryTypeDef"],
+        "creationTime": datetime,
+        "lastUpdateTime": datetime,
+    },
+    total=False,
+)
+
+PipelineTypeDef = TypedDict(
+    "PipelineTypeDef",
+    {
+        "name": str,
+        "arn": str,
+        "activities": List["PipelineActivityTypeDef"],
+        "reprocessingSummaries": List["ReprocessingSummaryTypeDef"],
+        "creationTime": datetime,
+        "lastUpdateTime": datetime,
+    },
+    total=False,
+)
+
+QueryFilterTypeDef = TypedDict("QueryFilterTypeDef", {"deltaTime": "DeltaTimeTypeDef"}, total=False)
+
 _RequiredRemoveAttributesActivityTypeDef = TypedDict(
     "_RequiredRemoveAttributesActivityTypeDef", {"name": str, "attributes": List[str]}
 )
@@ -517,6 +543,43 @@ class RemoveAttributesActivityTypeDef(
     pass
 
 
+ReprocessingSummaryTypeDef = TypedDict(
+    "ReprocessingSummaryTypeDef",
+    {
+        "id": str,
+        "status": Literal["RUNNING", "SUCCEEDED", "CANCELLED", "FAILED"],
+        "creationTime": datetime,
+    },
+    total=False,
+)
+
+ResourceConfigurationTypeDef = TypedDict(
+    "ResourceConfigurationTypeDef",
+    {"computeType": Literal["ACU_1", "ACU_2"], "volumeSizeInGB": int},
+)
+
+RetentionPeriodTypeDef = TypedDict(
+    "RetentionPeriodTypeDef", {"unlimited": bool, "numberOfDays": int}, total=False
+)
+
+_RequiredS3DestinationConfigurationTypeDef = TypedDict(
+    "_RequiredS3DestinationConfigurationTypeDef", {"bucket": str, "key": str, "roleArn": str}
+)
+_OptionalS3DestinationConfigurationTypeDef = TypedDict(
+    "_OptionalS3DestinationConfigurationTypeDef",
+    {"glueConfiguration": "GlueConfigurationTypeDef"},
+    total=False,
+)
+
+
+class S3DestinationConfigurationTypeDef(
+    _RequiredS3DestinationConfigurationTypeDef, _OptionalS3DestinationConfigurationTypeDef
+):
+    pass
+
+
+ScheduleTypeDef = TypedDict("ScheduleTypeDef", {"expression": str}, total=False)
+
 _RequiredSelectAttributesActivityTypeDef = TypedDict(
     "_RequiredSelectAttributesActivityTypeDef", {"name": str, "attributes": List[str]}
 )
@@ -531,216 +594,159 @@ class SelectAttributesActivityTypeDef(
     pass
 
 
-PipelineActivityTypeDef = TypedDict(
-    "PipelineActivityTypeDef",
+_RequiredSqlQueryDatasetActionTypeDef = TypedDict(
+    "_RequiredSqlQueryDatasetActionTypeDef", {"sqlQuery": str}
+)
+_OptionalSqlQueryDatasetActionTypeDef = TypedDict(
+    "_OptionalSqlQueryDatasetActionTypeDef", {"filters": List["QueryFilterTypeDef"]}, total=False
+)
+
+
+class SqlQueryDatasetActionTypeDef(
+    _RequiredSqlQueryDatasetActionTypeDef, _OptionalSqlQueryDatasetActionTypeDef
+):
+    pass
+
+
+TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
+
+TriggeringDatasetTypeDef = TypedDict("TriggeringDatasetTypeDef", {"name": str})
+
+_RequiredVariableTypeDef = TypedDict("_RequiredVariableTypeDef", {"name": str})
+_OptionalVariableTypeDef = TypedDict(
+    "_OptionalVariableTypeDef",
     {
-        "channel": ChannelActivityTypeDef,
-        "lambda": LambdaActivityTypeDef,
-        "datastore": DatastoreActivityTypeDef,
-        "addAttributes": AddAttributesActivityTypeDef,
-        "removeAttributes": RemoveAttributesActivityTypeDef,
-        "selectAttributes": SelectAttributesActivityTypeDef,
-        "filter": FilterActivityTypeDef,
-        "math": MathActivityTypeDef,
-        "deviceRegistryEnrich": DeviceRegistryEnrichActivityTypeDef,
-        "deviceShadowEnrich": DeviceShadowEnrichActivityTypeDef,
+        "stringValue": str,
+        "doubleValue": float,
+        "datasetContentVersionValue": "DatasetContentVersionValueTypeDef",
+        "outputFileUriValue": "OutputFileUriValueTypeDef",
     },
     total=False,
 )
 
-ReprocessingSummaryTypeDef = TypedDict(
-    "ReprocessingSummaryTypeDef",
-    {
-        "id": str,
-        "status": Literal["RUNNING", "SUCCEEDED", "CANCELLED", "FAILED"],
-        "creationTime": datetime,
-    },
+
+class VariableTypeDef(_RequiredVariableTypeDef, _OptionalVariableTypeDef):
+    pass
+
+
+VersioningConfigurationTypeDef = TypedDict(
+    "VersioningConfigurationTypeDef", {"unlimited": bool, "maxVersions": int}, total=False
+)
+
+BatchPutMessageResponseTypeDef = TypedDict(
+    "BatchPutMessageResponseTypeDef",
+    {"batchPutMessageErrorEntries": List["BatchPutMessageErrorEntryTypeDef"]},
     total=False,
 )
 
-PipelineTypeDef = TypedDict(
-    "PipelineTypeDef",
-    {
-        "name": str,
-        "arn": str,
-        "activities": List[PipelineActivityTypeDef],
-        "reprocessingSummaries": List[ReprocessingSummaryTypeDef],
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
-    },
+CreateChannelResponseTypeDef = TypedDict(
+    "CreateChannelResponseTypeDef",
+    {"channelName": str, "channelArn": str, "retentionPeriod": "RetentionPeriodTypeDef"},
+    total=False,
+)
+
+CreateDatasetContentResponseTypeDef = TypedDict(
+    "CreateDatasetContentResponseTypeDef", {"versionId": str}, total=False
+)
+
+CreateDatasetResponseTypeDef = TypedDict(
+    "CreateDatasetResponseTypeDef",
+    {"datasetName": str, "datasetArn": str, "retentionPeriod": "RetentionPeriodTypeDef"},
+    total=False,
+)
+
+CreateDatastoreResponseTypeDef = TypedDict(
+    "CreateDatastoreResponseTypeDef",
+    {"datastoreName": str, "datastoreArn": str, "retentionPeriod": "RetentionPeriodTypeDef"},
+    total=False,
+)
+
+CreatePipelineResponseTypeDef = TypedDict(
+    "CreatePipelineResponseTypeDef", {"pipelineName": str, "pipelineArn": str}, total=False
+)
+
+DescribeChannelResponseTypeDef = TypedDict(
+    "DescribeChannelResponseTypeDef",
+    {"channel": "ChannelTypeDef", "statistics": "ChannelStatisticsTypeDef"},
+    total=False,
+)
+
+DescribeDatasetResponseTypeDef = TypedDict(
+    "DescribeDatasetResponseTypeDef", {"dataset": "DatasetTypeDef"}, total=False
+)
+
+DescribeDatastoreResponseTypeDef = TypedDict(
+    "DescribeDatastoreResponseTypeDef",
+    {"datastore": "DatastoreTypeDef", "statistics": "DatastoreStatisticsTypeDef"},
+    total=False,
+)
+
+DescribeLoggingOptionsResponseTypeDef = TypedDict(
+    "DescribeLoggingOptionsResponseTypeDef",
+    {"loggingOptions": "LoggingOptionsTypeDef"},
     total=False,
 )
 
 DescribePipelineResponseTypeDef = TypedDict(
-    "DescribePipelineResponseTypeDef", {"pipeline": PipelineTypeDef}, total=False
-)
-
-DatasetContentStatusTypeDef = TypedDict(
-    "DatasetContentStatusTypeDef",
-    {"state": Literal["CREATING", "SUCCEEDED", "FAILED"], "reason": str},
-    total=False,
-)
-
-DatasetEntryTypeDef = TypedDict(
-    "DatasetEntryTypeDef", {"entryName": str, "dataURI": str}, total=False
+    "DescribePipelineResponseTypeDef", {"pipeline": "PipelineTypeDef"}, total=False
 )
 
 GetDatasetContentResponseTypeDef = TypedDict(
     "GetDatasetContentResponseTypeDef",
     {
-        "entries": List[DatasetEntryTypeDef],
+        "entries": List["DatasetEntryTypeDef"],
         "timestamp": datetime,
-        "status": DatasetContentStatusTypeDef,
-    },
-    total=False,
-)
-
-CustomerManagedChannelS3StorageSummaryTypeDef = TypedDict(
-    "CustomerManagedChannelS3StorageSummaryTypeDef",
-    {"bucket": str, "keyPrefix": str, "roleArn": str},
-    total=False,
-)
-
-ChannelStorageSummaryTypeDef = TypedDict(
-    "ChannelStorageSummaryTypeDef",
-    {
-        "serviceManagedS3": Dict[str, Any],
-        "customerManagedS3": CustomerManagedChannelS3StorageSummaryTypeDef,
-    },
-    total=False,
-)
-
-ChannelSummaryTypeDef = TypedDict(
-    "ChannelSummaryTypeDef",
-    {
-        "channelName": str,
-        "channelStorage": ChannelStorageSummaryTypeDef,
-        "status": Literal["CREATING", "ACTIVE", "DELETING"],
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
+        "status": "DatasetContentStatusTypeDef",
     },
     total=False,
 )
 
 ListChannelsResponseTypeDef = TypedDict(
     "ListChannelsResponseTypeDef",
-    {"channelSummaries": List[ChannelSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-DatasetContentSummaryTypeDef = TypedDict(
-    "DatasetContentSummaryTypeDef",
-    {
-        "version": str,
-        "status": DatasetContentStatusTypeDef,
-        "creationTime": datetime,
-        "scheduleTime": datetime,
-        "completionTime": datetime,
-    },
+    {"channelSummaries": List["ChannelSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListDatasetContentsResponseTypeDef = TypedDict(
     "ListDatasetContentsResponseTypeDef",
-    {"datasetContentSummaries": List[DatasetContentSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-DatasetActionSummaryTypeDef = TypedDict(
-    "DatasetActionSummaryTypeDef",
-    {"actionName": str, "actionType": Literal["QUERY", "CONTAINER"]},
-    total=False,
-)
-
-DatasetSummaryTypeDef = TypedDict(
-    "DatasetSummaryTypeDef",
-    {
-        "datasetName": str,
-        "status": Literal["CREATING", "ACTIVE", "DELETING"],
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
-        "triggers": List[DatasetTriggerTypeDef],
-        "actions": List[DatasetActionSummaryTypeDef],
-    },
+    {"datasetContentSummaries": List["DatasetContentSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListDatasetsResponseTypeDef = TypedDict(
     "ListDatasetsResponseTypeDef",
-    {"datasetSummaries": List[DatasetSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-CustomerManagedDatastoreS3StorageSummaryTypeDef = TypedDict(
-    "CustomerManagedDatastoreS3StorageSummaryTypeDef",
-    {"bucket": str, "keyPrefix": str, "roleArn": str},
-    total=False,
-)
-
-DatastoreStorageSummaryTypeDef = TypedDict(
-    "DatastoreStorageSummaryTypeDef",
-    {
-        "serviceManagedS3": Dict[str, Any],
-        "customerManagedS3": CustomerManagedDatastoreS3StorageSummaryTypeDef,
-    },
-    total=False,
-)
-
-DatastoreSummaryTypeDef = TypedDict(
-    "DatastoreSummaryTypeDef",
-    {
-        "datastoreName": str,
-        "datastoreStorage": DatastoreStorageSummaryTypeDef,
-        "status": Literal["CREATING", "ACTIVE", "DELETING"],
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
-    },
+    {"datasetSummaries": List["DatasetSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListDatastoresResponseTypeDef = TypedDict(
     "ListDatastoresResponseTypeDef",
-    {"datastoreSummaries": List[DatastoreSummaryTypeDef], "nextToken": str},
-    total=False,
-)
-
-PipelineSummaryTypeDef = TypedDict(
-    "PipelineSummaryTypeDef",
-    {
-        "pipelineName": str,
-        "reprocessingSummaries": List[ReprocessingSummaryTypeDef],
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
-    },
+    {"datastoreSummaries": List["DatastoreSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
 ListPipelinesResponseTypeDef = TypedDict(
     "ListPipelinesResponseTypeDef",
-    {"pipelineSummaries": List[PipelineSummaryTypeDef], "nextToken": str},
+    {"pipelineSummaries": List["PipelineSummaryTypeDef"], "nextToken": str},
     total=False,
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"key": str, "value": str})
-
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"tags": List[TagTypeDef]}, total=False
+    "ListTagsForResourceResponseTypeDef", {"tags": List["TagTypeDef"]}, total=False
 )
 
-MessageTypeDef = TypedDict("MessageTypeDef", {"messageId": str, "payload": Union[bytes, IO]})
+MessageTypeDef = TypedDict("MessageTypeDef", {"messageId": str, "payload": bytes})
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
 RunPipelineActivityResponseTypeDef = TypedDict(
-    "RunPipelineActivityResponseTypeDef",
-    {"payloads": List[Union[bytes, IO]], "logResult": str},
-    total=False,
+    "RunPipelineActivityResponseTypeDef", {"payloads": List[bytes], "logResult": str}, total=False
 )
 
 SampleChannelDataResponseTypeDef = TypedDict(
-    "SampleChannelDataResponseTypeDef", {"payloads": List[Union[bytes, IO]]}, total=False
+    "SampleChannelDataResponseTypeDef", {"payloads": List[bytes]}, total=False
 )
 
 StartPipelineReprocessingResponseTypeDef = TypedDict(
